==> egg-foundation-1.0.0-20210906.113133-1-sources.jar: com/bxm/egg/common/constant/InviteTypeEnum.java <==
package com.bxm.egg.common.constant;

public enum InviteTypeEnum {
    /**
     * 全部
     **/
    ALL("全部"),
    /**
     * 新闻
     **/
    NEWS("新闻"),
    /**
     * 活动
     */
    ACTIVITY("活动"),
    /**
     * 商户
     */
    MERCHANT("商户"),
    /**
     * 小程序抽奖
     */
    APPLETDRAW("邀请"),

    /**
     * H5抽奖
     */
    H5DRAW("邀请"),

    /**
     * VIP（历史版本的VIP）
     */
    VIP("vip邀请"),
    /**
     * 面对面邀请
     */
    FACEINVITE("面对面邀请"),

    /**
     * 邀请赚钱
     */
    INVITE_MONEY("邀请赚钱"),

    /**
     * 线下推广
     */
    OFFLINE("地推码"),

    /**
     * 帖子
     */
    FORUM("帖子"),

    /**
     * 话题
     */
    TOPIC("话题"),

    /**
     * h5推广赚钱分享
     */
    H5PROMOTE("邀请"),

    /**
     * 口令红包
     */
    RED_PACKET("口令红包"),

    /**
     * 万事通小程序
     */
    MINI_WST("万事通小程序"),

    /**
     * 摇钱树
     */
    MONEY_TREE("摇钱树"),

    /**
     * 个人主页邀请
     */
    PERSONAL_HOMEPAGE("个人主页"),

    /**
     * 好友邀请下载
     */
    FRIEND_INVITE("好友邀请下载"),

    /**
     * 蓝天救援队邀请
     */
    BLUE_SKY("蓝天救援队"),

    /**
     * 分享聊天室到站外，引导下载
     */
    CHATROOM("群聊邀请"),

    /**
     * 3.2.0：新做的福利VIP
     */
    WELFARE_VIP("邀请开卡福利VIP"),

    /**
     * 3.2.0：通过邀请码达成邀请关系
     */
    ACTIVE_CODE("激活码邀请的福利VIP"),

    /**
     * 3.2.0 : 分享返利商品
     */
    REBATE("返利商品"),
    /**
     * 3.3.0 :分享海报
     */
    POSTERS_SHARE("分享海报邀请");
    private String desc;

    InviteTypeEnum(String desc) {
        this.desc = desc;
    }

    public String getName() {
        return this.name();
    }

    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc;
    }
}

==> egg-foundation-1.0.0-20211012.081744-22-sources.jar: com/bxm/egg/common/constant/InviteTypeEnum.java <==
package com.bxm.egg.common.constant;

public enum InviteTypeEnum {
    /**
     * 全部
     **/
    ALL("全部"),
    /**
     * 新闻
     **/
    NEWS("新闻"),
    /**
     * 活动
     */
    ACTIVITY("活动"),
    /**
     * 商户
     */
    MERCHANT("商户"),
    /**
     * 小程序抽奖
     */
    APPLETDRAW("邀请"),

    /**
     * H5抽奖
     */
    H5DRAW("邀请"),

    /**
     * VIP（历史版本的VIP）
     */
    VIP("vip邀请"),
    /**
     * 面对面邀请
     */
    FACEINVITE("面对面邀请"),

    /**
     * 邀请赚钱
     */
    INVITE_MONEY("邀请赚钱"),

    /**
     * 线下推广
     */
    OFFLINE("地推码"),

    /**
     * 帖子
     */
    FORUM("帖子"),

    /**
     * 话题
     */
    TOPIC("话题"),

    /**
     * h5推广赚钱分享
     */
    H5PROMOTE("邀请"),

    /**
     * 口令红包
     */
    RED_PACKET("口令红包"),

    /**
     * 万事通小程序
     */
    MINI_WST("万事通小程序"),

    /**
     * 摇钱树
     */
    MONEY_TREE("摇钱树"),

    /**
     * 个人主页邀请
     */
    PERSONAL_HOMEPAGE("个人主页"),

    /**
     * 好友邀请下载
     */
    FRIEND_INVITE("好友邀请下载"),

    /**
     * 蓝天救援队邀请
     */
    BLUE_SKY("蓝天救援队"),

    /**
     * 分享聊天室到站外，引导下载
     */
    CHATROOM("群聊邀请"),

    /**
     * 3.2.0：新做的福利VIP
     */
    WELFARE_VIP("邀请开卡福利VIP"),

    /**
     * 3.2.0：通过邀请码达成邀请关系
     */
    ACTIVE_CODE("激活码邀请的福利VIP"),

    /**
     * 3.2.0 : 分享返利商品
     */
    REBATE("返利商品"),
    /**
     * 3.3.0 :分享海报
     */
    POSTERS_SHARE("分享海报邀请"),

    /**
     * 3.5.0 : 商户邀请员工绑定信息
     */
    BOSS_INVITE("商户邀请员工绑定"),

    /**
     * 3.6.0 : 商品分享邀请
     */
    WST_GOODS_SHARE("万事通商品分享邀请"),
    ;

    // 注意长度不要超过10

    private String desc;

    InviteTypeEnum(String desc) {
        this.desc = desc;
    }

    public String getName() {
        return this.name();
    }

    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc;
    }
}
